@@ -42,7 +42,7 @@ def load_dll(libname, fallbacks=None):
         raise OSError(
             "Could not find library %s or load any of its variants %s" % (
                 libname, fallbacks or []))
-       
+
 if sys.platform.startswith('linux'):
     _lgeos = load_dll('geos_c', fallbacks=['libgeos_c.so.1', 'libgeos_c.so'])
     free = load_dll('c').free
@@ -94,13 +94,15 @@ def _geos_c_version():
     func = _lgeos.GEOSversion
     func.argtypes = []
     func.restype = c_char_p
-    v = func().split('-')[2]
+    v = func()
+    c_ver = v.split('-')[2]
     # Ditch any SVN revision numbering that may have crept in without (ftm)
     # importing `re`.
-    v = v.split()[0]
-    return tuple(int(n) for n in v.split('.'))
+    c_ver = c_ver.split()[0]
+    return tuple(int(n) for n in c_ver.split('.')), v
 
-geos_capi_version = geos_c_version = _geos_c_version()
+geos_capi_version, geos_version_string = _geos_c_version()
+geos_c_version = geos_capi_version
 
 # If we have the new interface, then record a baseline so that we know what
 # additional functions are declared in ctypes_declarations.
@@ -115,7 +117,7 @@ prototype(_lgeos, geos_c_version)
 if geos_c_version >= (1,5,0):
     end_set = set(_lgeos.__dict__)
     new_func_names = end_set - start_set
-    
+
     for func_name in new_func_names:
         new_func_name = "%s_r" % func_name
         if hasattr(_lgeos, new_func_name):
@@ -130,7 +132,7 @@ if geos_c_version >= (1,5,0):
                 new_func.argtypes = [c_void_p] + old_func.argtypes
             if old_func.errcheck is not None:
                 new_func.errcheck = old_func.errcheck
-    
+
     # Handle special case.
     _lgeos.initGEOS_r.restype = c_void_p
     _lgeos.initGEOS_r.argtypes = [EXCEPTION_HANDLER_FUNCTYPE, EXCEPTION_HANDLER_FUNCTYPE]
@@ -195,9 +197,9 @@ class LGEOSBase(threading.local):
     def __init__(self, dll):
         self._lgeos = dll
         self.geos_handle = None
-        
 
-class LGEOS14(LGEOSBase):    
+
+class LGEOS14(LGEOSBase):
     """Proxy for the GEOS_C DLL/SO API version 1.4
     """
     geos_capi_version = (1, 4, 0)
@@ -259,12 +261,13 @@ class LGEOS14(LGEOSBase):
         self.methods['simplify'] = self.GEOSSimplify
         self.methods['topology_preserve_simplify'] = \
             self.GEOSTopologyPreserveSimplify
+        self.methods['cascaded_union'] = self.GEOSUnionCascaded
 
 
-class LGEOS15(LGEOSBase):    
+class LGEOS15(LGEOSBase):
     """Proxy for the reentrant GEOS_C DLL/SO API version 1.5
     """
-    geos_capi_version = (1, 5, 0)    
+    geos_capi_version = (1, 5, 0)
     def __init__(self, dll):
         super(LGEOS15, self).__init__(dll)
         self.geos_handle = self._lgeos.initGEOS_r(notice_h, error_h)
@@ -300,7 +303,7 @@ class LGEOS15(LGEOSBase):
             pred.func.errcheck = errcheck_predicate
 
         self.GEOSisValidReason.func.errcheck = errcheck_just_free
-        
+
         self.methods['area'] = self.GEOSArea
         self.methods['boundary'] = self.GEOSBoundary
         self.methods['buffer'] = self.GEOSBuffer
@@ -337,6 +340,8 @@ class LGEOS15(LGEOSBase):
         self.methods['simplify'] = self.GEOSSimplify
         self.methods['topology_preserve_simplify'] = \
             self.GEOSTopologyPreserveSimplify
+        self.methods['cascaded_union'] = self.GEOSUnionCascaded
+
 
 class LGEOS16(LGEOS15):
     """Proxy for the reentrant GEOS_C DLL/SO API version 1.6
@@ -346,7 +351,7 @@ class LGEOS16(LGEOS15):
         super(LGEOS16, self).__init__(dll)
 
 
-class LGEOS16LR(LGEOS16):    
+class LGEOS16LR(LGEOS16):
     """Proxy for the reentrant GEOS_C DLL/SO API version 1.6 with linear
     referencing
     """
@@ -362,7 +367,20 @@ class LGEOS16LR(LGEOS16):
             self.GEOSInterpolateNormalized
 
 
-if geos_c_version >= (1, 6, 0):
+class LGEOS17(LGEOS16LR):
+    """Proxy for the reentrant GEOS_C DLL/SO API version 1.7
+    """
+    geos_capi_version = (1, 7, 0)
+    def __init__(self, dll):
+        super(LGEOS17, self).__init__(dll)
+
+        self.methods['unary_union'] = self.GEOSUnaryUnion
+        self.methods['cascaded_union'] = self.methods['unary_union']
+
+
+if geos_c_version >= (1, 7, 0):
+    L = LGEOS17
+elif geos_c_version >= (1, 6, 0):
     if hasattr(_lgeos, 'GEOSProject'):
         L = LGEOS16LR
     else:
