@@ -4,7 +4,7 @@ import test_doctests, test_prepared, test_equality, test_geomseq, test_xy
 import test_collection, test_emptiness, test_singularity, test_validation
 import test_mapping, test_delegated, test_dlls, test_linear_referencing
 import test_products_z, test_box, test_speedups, test_cga, test_getitem
-import test_ndarrays
+import test_ndarrays, test_unary_union
 
 def test_suite():
     suite = TestSuite()
@@ -27,5 +27,6 @@ def test_suite():
     suite.addTest(test_cga.test_suite())
     suite.addTest(test_getitem.test_suite())
     suite.addTest(test_ndarrays.test_suite())
+    suite.addTest(test_unary_union.test_suite())
     return suite
 
